nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

Fdfd

Enum Fdfd 

#[repr(u8)]
pub enum Fdfd { FDFD0 = 0, FDFD1 = 1, }

Variants



FDFD0 = 0

FSTAT[DFDIF] sets only if a double bit fault is detected during a valid flash read access from the platform flash controller



FDFD1 = 1

FSTAT[DFDIF] sets during any valid flash read access from the platform flash controller. An interrupt request is generated if the DFDIE bit is set.

Implementations

Source

impl Fdfd

pub const fn from_bits(val: u8) -> Fdfd

pub const fn to_bits(self) -> u8